caellion-python-commons: caellion.pycommons.stringutil.unixpassword Namespace Reference

caellion-python-commons

Classes
caellion.pycommons.stringutil.unixpassword Namespace Reference

This module provides utlilities related to creating, reading, writing and parsing of linux-style passwd/shadow file. More...

## Classes
class | DuplicateFieldException
| This exception is raised when more than exactly one instance of a given field is contained within field list. More...
class | EmptyFieldNameException
| This exception is raised when an empty field name is encountered. More...
class | SeparatorEmptyException
| This exception is raised when an empty separator string is encountered. More...
class | NewlineEmptyException
| This exception is raised when an empty line separator string is encountered. More...
class | InvalidFileFormatException
| This exception is raised when encountering invalid or non-uniform line. More...
class | UnixPasswordText
| This class provides methods to read and write to linux-style passwd/shadow files, ability to parse shadow-style lines into dicts and identifying password hashing algorithms used in linux-style hash format. More...

## Detailed Description

This module provides utlilities related to creating, reading, writing and parsing of linux-style passwd/shadow file.